"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    (Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the DisassociateFromAdministratorAccount operation.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.from_.master_account.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.from_.master_account.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="disassociate_from_master_account",
        op_kwargs={},
    )
