"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def verify(hub, ctx, email_address: str) -> None:
    r"""
    **Autogenerated function**

    Deprecated. Use the VerifyEmailIdentity operation to verify a new email address.

    Args:
        email_address(str): The email address to be verified.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.email.address.verify(ctx, email_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.email.address.verify email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="verify_email_address",
        op_kwargs={"EmailAddress": email_address},
    )
