"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    association_id: str,
    execution_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Views information about a specific execution of a specific association.

    Args:
        association_id(str): The association ID that includes the execution for which you want to view details.
        execution_id(str): The execution ID for which you want to view details.
        filters(List, optional): Filters for the request. You can specify the following filters and values. Status (EQUAL) ResourceId (EQUAL) ResourceType (EQUAL). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.execution.target.describe_all(
                ctx, association_id=value, execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.execution.target.describe_all association_id=value, execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_association_execution_targets",
        op_kwargs={
            "AssociationId": association_id,
            "ExecutionId": execution_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
