"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def put_multiple(hub, ctx, dataset_arn: str, items: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more items to an Items dataset. For more information see Importing Items Incrementally.

    Args:
        dataset_arn(str): The Amazon Resource Name (ARN) of the Items dataset you are adding the item or items to.
        items(List): A list of item data.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize_event.item.put_multiple(
                ctx, dataset_arn=value, items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize_event.item.put_multiple dataset_arn=value, items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize-events",
        operation="put_items",
        op_kwargs={"datasetArn": dataset_arn, "items": items},
    )
