"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Provides the sending limits for the Amazon SES account.  You can execute this operation no more than once per second.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.send.quota.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.send.quota.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ses", operation="get_send_quota", op_kwargs={}
    )
